@@ -11,6 +11,12 @@
 
 #pragma once
 
+#include "config-kwin.h"
+
+#if !KWIN_BUILD_X11
+#error Do not include on non-X11 builds
+#endif
+
 #include "utils/xcbutils.h"
 
 namespace KWin
@@ -76,6 +82,7 @@ public:
     Xcb::Atom wl_selection;
     Xcb::Atom primary;
     Xcb::Atom edid;
+    Xcb::Atom xwayland_allow_commits;
 
     /**
      * @internal
