@@ -46,9 +46,6 @@ DrmPipeline::DrmPipeline(DrmConnector *conn)
 
 DrmPipeline::~DrmPipeline()
 {
-    if (pageflipsPending()) {
-        gpu()->waitIdle();
-    }
 }
 
 DrmPipeline::Error DrmPipeline::present(const std::shared_ptr<OutputFrame> &frame)
@@ -511,9 +508,9 @@ void DrmPipeline::revertPendingChanges()
     m_pending = m_next;
 }
 
-bool DrmPipeline::pageflipsPending() const
+DrmCommitThread *DrmPipeline::commitThread() const
 {
-    return m_commitThread->pageflipsPending();
+    return m_commitThread.get();
 }
 
 bool DrmPipeline::modesetPresentPending() const
