@@ -76,7 +76,7 @@ public:
 
     GraphicsBufferAllocator *graphicsBufferAllocator() const;
 
-    void present(Output *output, const std::shared_ptr<OutputFrame> &frame) override;
+    bool present(Output *output, const std::shared_ptr<OutputFrame> &frame) override;
     OutputLayer *primaryLayer(Output *output) override;
     OutputLayer *cursorLayer(Output *output) override;
 
