@@ -6,7 +6,7 @@
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
-#include <config-kwin.h>
+#include "config-kwin.h"
 
 #include "appmenu.h"
 #include "compositor.h"
@@ -80,6 +80,7 @@ static void initButtons()
     s_buttonNames[KDecoration2::DecorationButtonType::KeepAbove] = QChar('F');
     s_buttonNames[KDecoration2::DecorationButtonType::KeepBelow] = QChar('B');
     s_buttonNames[KDecoration2::DecorationButtonType::Shade] = QChar('L');
+    s_buttonNames[KDecoration2::DecorationButtonType::Spacer] = QChar('_');
 }
 
 static QString buttonsToString(const QList<KDecoration2::DecorationButtonType> &buttons)
