@@ -11,7 +11,6 @@
 
 #include <QList>
 #include <QRectF>
-#include <netwm_def.h>
 
 #include "options.h"
 #include "utils/common.h"
@@ -26,6 +25,7 @@ class Window;
 class Output;
 class Rules;
 class RuleSettings;
+class RuleBookSettings;
 class VirtualDesktop;
 
 #ifndef KCMRULES // only for kwin core
@@ -77,6 +77,8 @@ public:
     bool checkDisableGlobalShortcuts(bool disable) const;
     QString checkDesktopFile(QString desktopFile, bool init = false) const;
     Layer checkLayer(Layer layer) const;
+    bool checkAdaptiveSync(bool adaptivesync) const;
+    bool checkTearing(bool requestsTearing) const;
 
 private:
     MaximizeMode checkMaximizeVert(MaximizeMode mode, bool init) const;
@@ -143,6 +145,8 @@ public:
     };
     void write(RuleSettings *) const;
     bool isEmpty() const;
+    QString id() const;
+
 #ifndef KCMRULES
     bool discardUsed(bool withdrawn);
     bool match(const Window *c) const;
@@ -185,10 +189,12 @@ public:
     bool applyDisableGlobalShortcuts(bool &disable) const;
     bool applyDesktopFile(QString &desktopFile, bool init) const;
     bool applyLayer(enum Layer &layer) const;
+    bool applyAdaptiveSync(bool &adaptivesync) const;
+    bool applyTearing(bool &tearing) const;
 
 private:
 #endif
-    bool matchType(NET::WindowType match_type) const;
+    bool matchType(WindowType match_type) const;
     bool matchWMClass(const QString &match_class, const QString &match_name) const;
     bool matchRole(const QString &match_role) const;
     bool matchTitle(const QString &match_title) const;
@@ -207,6 +213,7 @@ private:
 #endif
     enum Layer layer;
     ForceRule layerrule;
+    QString m_id;
     QString description;
     QString wmclass;
     StringMatch wmclassmatch;
@@ -217,7 +224,7 @@ private:
     StringMatch titlematch;
     QString clientmachine;
     StringMatch clientmachinematch;
-    NET::WindowTypes types; // types for matching
+    WindowTypes types; // types for matching
     PlacementPolicy placement;
     ForceRule placementrule;
     QPoint position;
@@ -288,6 +295,10 @@ private:
     ForceRule disableglobalshortcutsrule;
     QString desktopfile;
     SetRule desktopfilerule;
+    bool adaptivesync;
+    ForceRule adaptivesyncrule;
+    bool tearing;
+    ForceRule tearingrule;
     friend QDebug &operator<<(QDebug &stream, const Rules *);
 };
 
@@ -305,11 +316,7 @@ public:
     void load();
     void edit(Window *c, bool whole_app);
     void requestDiskStorage();
-
-    void setConfig(const KSharedConfig::Ptr &config)
-    {
-        m_config = config;
-    }
+    void setConfig(const KSharedConfig::Ptr &config);
 
 private Q_SLOTS:
     void save();
@@ -319,7 +326,7 @@ private:
     QTimer *m_updateTimer;
     bool m_updatesDisabled;
     QList<Rules *> m_rules;
-    KSharedConfig::Ptr m_config;
+    std::unique_ptr<RuleBookSettings> m_book;
 };
 
 inline bool RuleBook::areUpdatesDisabled() const
